Recipe
Cell descriptions
Cell 0
Morphology
Segment Tree
Segment 0 (soma)
Decor
Paintables
hh `(all)`
Placables
iclamp `"midsoma"`
detector_0 `"midsoma"`
Label dictionary
midsoma `(location 0 0.5)`
Cell 1
Morphology
Segment Tree
Segment 0 (soma)
Segment 1 (dendrite)
Segment 2 (dendrite)
Segment ...
Decor
Paintables
passive `(all)`
Placables
synapse_1 `"endpoint"`
gap_junction_1 `"midsoma"`
Label dictionary
midsoma `(location 0 0.5)`
endpoint `(terminal)`
Cell 2
Morphology
Segment Tree
Segment 0 (soma)
Segment 1 (dendrite)
Segment 2 (dendrite)
Segment ...
Decor
Paintables
passive `(all)`
Placables
gap_junction_2 `"midsoma"`
Label dictionary
midsoma `(location 0 0.5)`
Cell kinds
Cell 0
type `arbor.cable_cell`
Cell 1
type `arbor.cable_cell`
Cell 2
type `arbor.cable_cell`
Connections
Connection 1
from `detector_0`
to `synapse_1`
Gap Junction 1
from `gap_junction_1`
to `gap_junction_2`
Probes
Probe 1
gid `2`
An example recipe. Click "+" and "-" to (de)collapse contents.